@@ -113,9 +113,15 @@ class MainController(object):
               'default':"10025,10099,10888",
             },
             
+            'outgoinghost':{
+              'section':'main',
+              'description':"outgoing hostname/ip where postfix is listening for re-injects.\nuse ${injecthost} to connect back to the IP where the incoming connection came from",
+              'default':"127.0.0.1",
+            },
+            
             'outgoingport':{
               'section':'main',
-              'description':"outgoing port (what port does postfix listen for re-injects)",
+              'description':"outgoing port  where postfix is listening for re-injects)",
               'default':"10026",
             },
                 
@@ -269,6 +275,11 @@ class MainController(object):
                 'section':'PluginAlias',
             },
                            
+            'fraction':{
+                'default':"fuglu.plugins.p_fraction.PluginFraction",
+                'section':'PluginAlias',
+            },
+            
             'archive':{
                 'default':"fuglu.plugins.archive.ArchivePlugin",
                 'section':'PluginAlias',
@@ -809,7 +820,20 @@ class MainController(object):
 
 ############################## UNIT TESTS ##########################################
 
-
+def guess_clamav_socket(config):
+    """depending on the test environment, clamav may be using a tcp port or running on a unix socket
+    try to guess the correct setting 
+    """
+    config.set('ClamavPlugin', 'port','3310')
+    #try local socket:
+    knownpaths=[
+      '/var/lib/clamav/clamd.sock',
+      '/var/run/clamav/clamd.ctl',
+    ]
+    for p in knownpaths:
+        if os.path.exists(p):
+            config.set('ClamavPlugin', 'port',p)
+            break
 
 class AllpluginTestCase(unittest.TestCase):
     """Tests that all plugins should pass"""
@@ -817,6 +841,7 @@ class AllpluginTestCase(unittest.TestCase):
         config=ConfigParser.RawConfigParser()
         config.read(['../conf/fuglu.conf.dist'])
         config.set('main', 'disablebounces', '1')
+        guess_clamav_socket(config)
         
         self.mc=MainController(config)
         self.tempfiles=[]
@@ -867,6 +892,7 @@ class AllpluginTestCase(unittest.TestCase):
 class EndtoEndTestTestCase(unittest.TestCase):
     """Full check if mail runs through"""
     
+    FUGLU_HOST="127.0.0.1"
     FUGLU_PORT=7711
     DUMMY_PORT=7712
     FUGLUCONTROL_PORT=7713
@@ -876,13 +902,15 @@ class EndtoEndTestTestCase(unittest.TestCase):
         self.config=ConfigParser.RawConfigParser()
         self.config.read(['testdata/endtoendtest.conf'])
         self.config.set('main','incomingport',str(EndtoEndTestTestCase.FUGLU_PORT))
+        self.config.set('main','outgoinghost',str(EndtoEndTestTestCase.FUGLU_HOST))
         self.config.set('main','outgoingport',str(EndtoEndTestTestCase.DUMMY_PORT))
         self.config.set('main','controlport',str(EndtoEndTestTestCase.FUGLUCONTROL_PORT))
+        guess_clamav_socket(self.config)
         #init core
         self.mc=MainController(self.config)
         
         #start listening smtp dummy server to get fuglus answer
-        self.smtp=DummySMTPServer(self.config, EndtoEndTestTestCase.DUMMY_PORT, "127.0.0.1")
+        self.smtp=DummySMTPServer(self.config, EndtoEndTestTestCase.DUMMY_PORT, EndtoEndTestTestCase.FUGLU_HOST)
         thread.start_new_thread(self.smtp.serve, ())
         
         #start fuglus listening server
@@ -931,6 +959,7 @@ Don't dare you change any of my bytes or even remove one!"""
 class DKIMTestCase(unittest.TestCase):
     """DKIM Sig Test"""
     
+    FUGLU_HOST="127.0.0.1"
     FUGLU_PORT=7731
     DUMMY_PORT=7732
     FUGLUCONTROL_PORT=7733
@@ -941,13 +970,16 @@ class DKIMTestCase(unittest.TestCase):
         self.config=ConfigParser.RawConfigParser()
         self.config.read(['testdata/endtoendtest.conf'])
         self.config.set('main','incomingport',str(DKIMTestCase.FUGLU_PORT))
+        self.config.set('main','outgoinghost',str(DKIMTestCase.FUGLU_HOST))
         self.config.set('main','outgoingport',str(DKIMTestCase.DUMMY_PORT))
         self.config.set('main','controlport',str(DKIMTestCase.FUGLUCONTROL_PORT))
+        guess_clamav_socket(self.config)
+        
         #init core
         self.mc=MainController(self.config)
         
         #start listening smtp dummy server to get fuglus answer
-        self.smtp=DummySMTPServer(self.config, self.config.getint('main', 'outgoingport'), "127.0.0.1")
+        self.smtp=DummySMTPServer(self.config, self.config.getint('main', 'outgoingport'), DKIMTestCase.FUGLU_HOST)
         thread.start_new_thread(self.smtp.serve, ())
         
         #start fuglus listening server
@@ -986,6 +1018,7 @@ class DKIMTestCase(unittest.TestCase):
         
         #verify the smtp server stored the file correctly
         tmpfile=self.smtp.tempfilename
+        self.assertTrue(tmpfile!=None,'Send to dummy smtp server failed')
         
         result=open(tmpfile,'r').read()
         logbuffer=cStringIO.StringIO()
@@ -995,6 +1028,7 @@ class DKIMTestCase(unittest.TestCase):
 class SMIMETestCase(unittest.TestCase):
     """Email Signature Tests"""
     
+    FUGLU_HOST="127.0.0.1"
     FUGLU_PORT=7721
     DUMMY_PORT=7722
     FUGLUCONTROL_PORT=7723
@@ -1005,13 +1039,16 @@ class SMIMETestCase(unittest.TestCase):
         self.config=ConfigParser.RawConfigParser()
         self.config.read(['testdata/endtoendtest.conf'])
         self.config.set('main','incomingport',str(SMIMETestCase.FUGLU_PORT))
+        self.config.set('main','outgoinghost',str(SMIMETestCase.FUGLU_HOST))
         self.config.set('main','outgoingport',str(SMIMETestCase.DUMMY_PORT))
         self.config.set('main','controlport',str(SMIMETestCase.FUGLUCONTROL_PORT))
+        guess_clamav_socket(self.config)
+        
         #init core
         self.mc=MainController(self.config)
         
         #start listening smtp dummy server to get fuglus answer
-        self.smtp=DummySMTPServer(self.config, SMIMETestCase.DUMMY_PORT, "127.0.0.1")
+        self.smtp=DummySMTPServer(self.config, SMIMETestCase.DUMMY_PORT, SMIMETestCase.FUGLU_HOST)
         thread.start_new_thread(self.smtp.serve, ())
         
         #start fuglus listening server
