@@ -202,7 +202,7 @@ Prerequisites: Requires a running sophos daemon with dynamic interface (SAVDI)
             self.logger.info('Not scanning - message too big')
             return
         
-        content=suspect.getSource()
+        content=suspect.get_source()
 
         for i in range(0,self.config.getint(self.section,'retries')):
             try:
