@@ -74,6 +74,11 @@ def actioncode_to_string(actioncode):
 def string_to_actioncode(actionstring,config=None):
     """return the code for this action"""
     upper=actionstring.upper().strip()
+    
+    #support DISCARD as alias for DELETE
+    if upper=='DISCARD':
+        upper='DELETE'
+    
     if config!=None:
         if upper=='DEFAULTHIGHSPAMACTION':
             confval=config.get('spam','defaulthighspamaction').upper()
@@ -231,10 +236,10 @@ class Suspect(object):
         except Exception,e:
             logging.getLogger('suspect').error('Could not write to logfile: %s'%e)
 
-    def get_tag(self,key):
-        """returns the tag value"""
+    def get_tag(self,key,defaultvalue=None):
+        """returns the tag value. if the tag is not found, return defaultvalue instead (None if no defaultvalue passed)"""
         if not self.tags.has_key(key):
-            return None
+            return defaultvalue
         return self.tags[key]
     
     def set_tag(self,key,value):
@@ -266,7 +271,7 @@ class Suspect(object):
             val=unicode(value,errors='ignore')  # is ignore the right thing to do here?
             hdr=Header(val, header_name=key, continuation_ws=' ')
             hdrline="%s: %s\n"%(key,hdr.encode())
-            src=hdrline+self.getSource()
+            src=hdrline+self.get_source()
             self.set_source(src)
         else:
             self.addheaders[key]=value
@@ -414,7 +419,7 @@ class Suspect(object):
 
     def get_headers(self):
         """returns the message headers as string"""
-        headers=re.split('(?:\n\n)|(?:\r\n\r\n)',self.getSource(maxbytes=1048576),1)[0]
+        headers=re.split('(?:\n\n)|(?:\r\n\r\n)',self.get_source(maxbytes=1048576),1)[0]
         return headers
     
     def get_client_info(self,config=None):
@@ -433,7 +438,7 @@ class Suspect(object):
             clientinfo= self.client_info_from_rcvd()
             
         else:
-            clientinfo= self.client_info_from_rcvd(config.get('environment','trustedhostsregex'), config.get('environment','boundarydistance'))
+            clientinfo= self.client_info_from_rcvd(config.get('environment','trustedhostsregex'), config.getint('environment','boundarydistance'))
         self.clientinfo=clientinfo
         return clientinfo
     
@@ -453,7 +458,7 @@ class Suspect(object):
         returns None if the client info can not be found or if all applicable values are filtered by skip/ignoreregex
         """
         ignorere=None
-        if ignoreregex!=None:
+        if ignoreregex!=None and ignoreregex!='':
             ignorere=re.compile(ignoreregex)
         
         unknown=None
@@ -463,7 +468,7 @@ class Suspect(object):
         receivedheaders=self.get_message_rep().get_all('Received')
         if receivedheaders==None:
             return unknown
-        
+
         for rcvdline in receivedheaders[skip:]:
             match=receivedpattern.search(rcvdline)
             if match==None:
@@ -758,7 +763,7 @@ class SuspectFilter(object):
         if headername=='to_domain':
             return [suspect.to_domain,]
         if headername=='body:full':
-            return [suspect.getOriginalSource()]
+            return [suspect.get_original_source()]
         
         #if it starts with a @ we return a tag, not a header
         if headername[0:1]=='@':
@@ -808,27 +813,35 @@ class SuspectFilter(object):
         return valuelist
            
            
-    def matches(self,suspect):
-        """returns (True,arg) if any regex matches, (False,None) otherwise"""
+    def matches(self,suspect,extended=False):
+        """returns (True,arg) if any regex matches, (False,None) otherwise
+        
+        if extended=True, returns all available info about the match in a tuple:
+        True, (fieldname, matchedvalue, arg, regex)
+        """
         self._reloadifnecessary()
         
         for tup in self.patterns:
-            (headername,pattern,arg)=tup
-            vals=self.get_field(suspect,headername)
+            (fieldname,pattern,arg)=tup
+            vals=self.get_field(suspect,fieldname)
             if vals==None or len(vals)==0:
-                self.logger.debug('No header %s found'%headername)
+                self.logger.debug('No field %s found'%fieldname)
                 continue
             
             for val in vals:
                 if val==None:
                     continue
-                #self.logger.debug("""Checking headername %s (arg '%s') regex '%s' against value %s"""%(headername,arg,pattern.pattern,val))
-                if pattern.search(str(val)):   
-                    self.logger.debug("""MATCH field %s (arg '%s') regex '%s' against value '%s'"""%(headername,arg,pattern.pattern,val))
-                    suspect.debug("message matches rule in %s: field=%s arg=%s regex=%s content=%s"%(self.filename,headername,arg,pattern.pattern,val))
-                    return (True,arg)
+                
+                strval=str(val)
+                if pattern.search(strval):   
+                    self.logger.debug("""MATCH field %s (arg '%s') regex '%s' against value '%s'"""%(fieldname,arg,pattern.pattern,val))
+                    suspect.debug("message matches rule in %s: field=%s arg=%s regex=%s content=%s"%(self.filename,fieldname,arg,pattern.pattern,val))
+                    if extended:
+                        return True,(fieldname,strval,arg,pattern.pattern)
+                    else:
+                        return (True,arg)
                 else:
-                    self.logger.debug("""NO MATCH field %s (arg '%s') regex '%s' against value '%s'"""%(headername,arg,pattern.pattern,val))
+                    self.logger.debug("""NO MATCH field %s (arg '%s') regex '%s' against value '%s'"""%(fieldname,arg,pattern.pattern,val))
                     
         self.logger.debug('No match found')
         suspect.debug("message does not match any rule in %s"%self.filename)
@@ -836,7 +849,7 @@ class SuspectFilter(object):
     
     def get_args(self,suspect,extended=False):
         """returns all args of matched regexes in a list
-        if extended=True, but returns a list of tuples with all available information:
+        if extended=True:  returns a list of tuples with all available information:
         (fieldname, matchedvalue, arg, regex)
         """
         ret=[]
@@ -909,8 +922,16 @@ class SuspectFilterTestCase(unittest.TestCase):
         self.failIf('this should not match' in headermatches,"rule flag ignorecase was not detected")
         
         #TODO: raw body rules
-        (match,arg)=self.candidate.matches(suspect)
+        
+        #extended
+        (match,info)=self.candidate.matches(suspect,extended=True)
         self.failUnless(match,'Match should return True')
+        field,matchedvalue,arg,regex=info
+        self.failUnless(field=='to_domain')
+        self.failUnless(matchedvalue=='unittests.fuglu.org')
+        self.failUnless(arg=='Sent to unittest domain!')
+        self.failUnless(regex=='unittests\.fuglu\.org')
+        
 
 class ActionCodeTestCase(unittest.TestCase):
     def test_defaultcodes(self):
@@ -926,6 +947,9 @@ class ActionCodeTestCase(unittest.TestCase):
         self.assertEqual(string_to_actioncode('defaultvirusaction', conf),REJECT)
         self.assertEqual(string_to_actioncode('nonexistingstuff'), None)
         self.assertEqual(actioncode_to_string(REJECT),'REJECT')
+        self.assertEqual(actioncode_to_string(string_to_actioncode('discard')), 'DELETE')
+        
+        
 
 
 class TemplateTestcase(unittest.TestCase):
